==> lunesrs-1.5.5.crate: lunesrs-1.5.5/README.md <==
<div align="center">

  <a href="https://lunes.io">
    <img alt="Lunes" src="static/lunesrs.png" width="100" />
  </a>

#  LunesRs

- Rust Library target WebAssembly and IoT for communication with nodes in mainnet or testnet of the lunes-blockchain network Allows the automation of sending assets, issue end reissue tokens, leasing, registry, and create new wallet.

[![Test](https://github.com/lunes-platform/lunesrs/actions/workflows/python-app.yml/badge.svg)](https://github.com/lunes-platform/lunesrs/actions/workflows/python-app.yml)
[![License](https://img.shields.io/github/license/lunes-platform/lunesrs?color=blueviolet)](LICENSE)
[![Stars](https://img.shields.io/github/stars/lunes-platform/lunesrs?color=blueviolet)](https://github.com/lunes-platform/lunesrs/stargazers)
[![CommitActivity](https://img.shields.io/github/commit-activity/m/lunes-platform/lunesrs?color=blueviolet)](https://github.com/lunes-platform/lunesrs/pulse)
[![Forks](https://img.shields.io/github/forks/lunes-platform/lunesrs?color=blueviolet)](https://github.com/lunes-platform/lunesrs/network/members)
[![Contributors](https://flat.badgen.net/github/contributors/lunes-platform/lunesrs?color=purple)](https://github.com/lunes-platform/lunesrs/graphs/contributors)
![ClosedIssue](https://flat.badgen.net/github/closed-issues/lunes-platform/lunesrs?color=red)
[![Branches](https://badgen.net/github/branches/lunes-platform/lunesrs?color=blueviolet)](https://github.com/lunes-platform/lunesrs/branches)
[![Watchers](https://img.shields.io/github/watchers/lunes-platform/lunesrs.svg?color=blueviolet)](https://github.com/lunes-platform/lunesrs/watchers)
[![Followers](https://img.shields.io/github/followers/lunes-platform.svg?style=social&label=Follow&maxAge=2592000?color=blueviolet)](https://github.com/lunes-platform?tab=followers)
[![Website](https://img.shields.io/website?url=https%3A%2F%2Flunes.io%2F)](https://lunes.io)
![PullRequest](https://img.shields.io/github/issues-pr/lunes-platform/lunesrs?color=blueviolet)
![PullRequestClosed](https://img.shields.io/github/issues-pr-closed/lunes-platform/lunesrs?color=blueviolet)

  <a href="https://twitter.com/LunesPlatform" target="_blank">
    <img alt="Twitter: Lunes Platform" src="https://badgen.net/twitter/follow/lunesplatform?icon=twitter&label=follow @LunesPlatform&color=blue" />
  </a>  
  <a href="https://t.me/LunesPlatformPT" target="_blank">
    <img alt="Telegram" src="https://badgen.net/badge/icon/Lunes%20Platform?icon=telegram&label=Telegram&color=blue"/>
  </a>

</div>

## Changelog

The changelog process for this project is described [here](CHANGELOG.md).

## Documentation

`lunesrs` documentations is hosted at [Telescope](https://blockchain.lunes.io/telescope/)

## Contributing

`lunesrs` is still under development. Contributions are always welcome! Please follow the [Developers Guide](CONTRIBUTING.md) if you want to help.

Thanks to the following people who have contributed to this project:

* [olivmath](https://github.com/olivmath)
* [nunesinc](https://github.com/nunesinc)
* [joelesteves](https://github.com/joelesteves)
* [xonfps](https://github.com/xonfps)

## Contact

If you want to contact me you can reach me at <development@lunes.io>.

## License

[Apache License Version 2.0](LICENSE).

==> lunesrs-1.8.1.crate: lunesrs-1.8.1/README.md <==
<div align="center">

  <a href="https://lunes.io">
    <img alt="Lunes" src="static/lunesrs.png" width="100" />
  </a>

#  LunesRs

- Rust Library target WebAssembly and IoT for communication with nodes in mainnet or testnet of the lunes-blockchain network Allows the automation of sending assets, issue end reissue tokens, leasing, registry, and create new wallet.

[![Build](https://github.com/lunes-platform/lunesrs/actions/workflows/build.yml/badge.svg)](https://github.com/lunes-platform/lunesrs/actions/workflows/build.yml)
[![Test](https://github.com/lunes-platform/lunesrs/actions/workflows/test.yml/badge.svg)](https://github.com/lunes-platform/lunesrs/actions/workflows/test.yml)
[![Stars](https://img.shields.io/github/stars/lunes-platform/lunesrs?color=blueviolet)](https://github.com/lunes-platform/lunesrs/stargazers)
[![Release](https://img.shields.io/github/v/release/lunes-platform/lunesrs)](https://github.com/lunes-platform/lunesrs/releases)
[![License](https://img.shields.io/github/license/lunes-platform/lunesrs?color=blueviolet)](LICENSE)

[![CommitActivity](https://img.shields.io/github/commit-activity/m/lunes-platform/lunesrs?color=blueviolet)](https://github.com/lunes-platform/lunesrs/pulse)
[![Forks](https://img.shields.io/github/forks/lunes-platform/lunesrs?color=blueviolet)](https://github.com/lunes-platform/lunesrs/network/members)
[![Contributors](https://flat.badgen.net/github/contributors/lunes-platform/lunesrs?color=purple)](https://github.com/lunes-platform/lunesrs/graphs/contributors)
![ClosedIssue](https://flat.badgen.net/github/closed-issues/lunes-platform/lunesrs?color=red)
[![Branches](https://badgen.net/github/branches/lunes-platform/lunesrs?color=blueviolet)](https://github.com/lunes-platform/lunesrs/branches)
[![Watchers](https://img.shields.io/github/watchers/lunes-platform/lunesrs.svg?color=blueviolet)](https://github.com/lunes-platform/lunesrs/watchers)
[![Followers](https://img.shields.io/github/followers/lunes-platform.svg?style=social&label=Follow&maxAge=2592000?color=blueviolet)](https://github.com/lunes-platform?tab=followers)
[![Website](https://img.shields.io/website?url=https%3A%2F%2Flunes.io%2F)](https://lunes.io)
![PullRequest](https://img.shields.io/github/issues-pr/lunes-platform/lunesrs?color=blueviolet)
![PullRequestClosed](https://img.shields.io/github/issues-pr-closed/lunes-platform/lunesrs?color=blueviolet)

  <a href="https://twitter.com/LunesPlatform" target="_blank">
    <img alt="Twitter: Lunes Platform" src="https://badgen.net/twitter/follow/lunesplatform?icon=twitter&label=follow @LunesPlatform&color=blue" />
  </a>  
  <a href="https://t.me/LunesPlatformPT" target="_blank">
    <img alt="Telegram" src="https://badgen.net/badge/icon/Lunes%20Platform?icon=telegram&label=Telegram&color=blue"/>
  </a>

</div>

## Changelog

The changelog process for this project is described [here](CHANGELOG.md).

## Documentation

`lunesrs` documentations is hosted at [Telescope](https://blockchain.lunes.io/telescope/)

## Contributing

`lunesrs` is still under development. Contributions are always welcome! Please follow the [Developers Guide](CONTRIBUTING.md) if you want to help.

Thanks to the following people who have contributed to this project:

[![GitHub Contributors Image](https://contrib.rocks/image?repo=lunes-platform/lunesrs)](https://github.com/lunes-platform/lunesrs/graphs/contributors)

## Contact

If you want to contact me you can reach me at <development@lunes.io>.

## License

[Apache License Version 2.0](LICENSE).
